==> flutter_insider-1.0.0.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';
import 'package:flutter_insider/flutter_insider.dart';
import 'package:flutter_insider/src/user.dart';
import 'package:flutter_insider/src/product.dart';
import 'package:flutter_insider/enum/InsiderGender.dart';
import 'package:flutter_insider/enum/InsiderCallbackAction.dart';
import 'package:flutter_insider/enum/ContentOptimizerDataType.dart';
void main() => runApp(MyApp());
class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}
class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  @override
  void initState() {
    super.initState();
    initInsider();
  }
  Future<void> initInsider() async {
    if (!mounted) return;
    await FlutterInsider.Instance.init("orkunbites", "test",
        (int type, dynamic data) {
      switch (type) {
        case InsiderCallbackAction.INAPP_BUTTON_CLICK:
          setState(() {
            _platformVersion = data.toString();
          });
          print("[INSIDER] : Callback Data: " + data.toString());
          break;
        case InsiderCallbackAction.NOTIFICATION_OPEN:
          setState(() {
            _platformVersion = data.toString();
          });
          print("[INSIDER] : Notification Callback Data: " + data.toString());
          break;
        default:
          print("[INSIDER] : Unregistered Action");
          break;
      }
    });
    FlutterInsider.Instance.registerWithQuietPermission(false);
    //regression();
  }
  void regression() {
    FlutterInsider.Instance.startTrackingGeofence();
    FlutterInsider.Instance.registerWithQuietPermission(false);
    //   FlutterInsider.Instance.getSmartRecommendation(1, "tr_TR", "TRY");
    //FlutterInsider.Instance.getContentBoolWithName("variableName", true, 12);
    // FlutterInsider.Instance.getContentIntWithName("variableName", 12, 212);
    // FlutterInsider.Instance.getContentStringWithName("variableName", "defaultValue", 23);
    FlutterInsiderProduct pro = FlutterInsider.Instance.createNewProduct("ID-123", "name-123", "TAX-123", "IMG-123", 523.23, "CUR-123");  //doğru
    pro.setQuantity(3); //doğru
    FlutterInsider.Instance.itemPurchased("sale-001", pro); //doğru e_guid
    FlutterInsiderProduct pro1 = FlutterInsider.Instance.createNewProduct("ID-124", "name-124", "TAX-124", "IMG-124", 10, "CUR-124");
    FlutterInsider.Instance.itemAddedToCart(pro1); //doğru
    FlutterInsider.Instance.cartCleared(); //doğru
    FlutterInsiderProduct pro7 = FlutterInsider.Instance.createNewProduct("ID-1", "name-2", "TAX-3", "IMG-4", 12.34, "CUR-5");// item added to cartın içinde quantity otomatik 1 aldı set ettiklerim doğru geldi aşağıda
    FlutterInsider.Instance.itemAddedToCart(pro7);//doğru
    pro7.setQuantity(-2); //doğru pozitif olanı aldı
    pro7.setQuantity(20); // doğru
    pro7.setColor("maviiiii");// YANLIŞ GELMEDİ?????????
    pro7.setStock(null);
    pro7.setStock(-2);
    pro7.setColor("#2131321");
    pro7.setVoucherName("test_v");//gelmedi
    pro7.setPromotionName("test_p");// gelmedi
    pro7.setPromotionName("azz_pro"); // YANLIŞ GELMEDİ ???????????
    pro7.setSize("size_21");//gelmedi
    pro7.setStock(0); // st doğru
    pro7.setSalePrice(1231.2121); // usp doğru
    pro7.setShippingCost(23); // sc doğru
    pro7.setVoucherDiscount(0); // vd doğru
    pro7.setPromotionDiscount(2); // pd 2 doğru
    pro7.setCustomAttributeWithString("my_name", "test_string"); // YANLIS GELMEDİİİİİİİİİİİİİİİİİİ ?
    pro7.setCustomAttributeWithBoolean("is_got", true); //doğru
    pro7.setCustomAttributeWithInt("inte_ger", 121212);//doğru
    pro7.setCustomAttributeWithDouble("double_double", 33333.2); // doğru
    pro7.setCustomAttributeWithDate("zaman_dursun", new DateTime.now()); //doğru
    pro7.setSubCategory("leg");//gelmedi
    List<String> trr = new List(4);
    trr[0] = "deneme1";
    trr[1] = "deneme22";
    trr[2] = "deneme3";
    trr[3] = null;
    pro7.setCustomAttributeWithArray("test_keko", trr); // doğru bosluklu yollayınca valid değil diyor.
    FlutterInsider.Instance.itemPurchased("123", pro7); // doğru e_guid
    FlutterInsiderProduct pro4 = FlutterInsider.Instance.createNewProduct(
        "ID-120", "name-120", "TAX-120", "IMG-120", 12.34, "CUR-120");
    pro4.setQuantity(4);
    FlutterInsider.Instance.itemPurchased(null, null);
    FlutterInsiderProduct pro3 = FlutterInsider.Instance.createNewProduct(
        "ID-122", "name-122", "TAX-122", "IMG-122", 12.34, "CUR-122");
    pro3.setQuantity(0);
    FlutterInsider.Instance.itemAddedToCart(pro3);
    List<FlutterInsiderProduct> products = new List(2);
    products[0] = pro4;
    products[1] = pro3;
    FlutterInsider.Instance.visitCartPage(products);
    FlutterInsider.Instance.visitHomePage(); //doğru
    // FlutterInsider.Instance.visitListingPage(null);
    FlutterInsider.Instance.visitListingPage("shooes");
    //   FlutterInsider.Instance.visitProductDetailPage(null);//doğru
    FlutterInsider.Instance.visitProductDetailPage(pro4);
    FlutterInsider.Instance.itemRemovedFromCart("5"); //doğru
    FlutterInsider.Instance.setGDPRConsent(true);
    //FlutterInsider.Instance.setGDPRConsent(false);
    List<String> arr = new List(4);
    arr[0] = "item1";
    arr[1] = "item2";
    arr[2] = "item3";
    arr[3] = null;
    //user
    DateTime time = new DateTime.now();
    FlutterInsiderUser insiderUser = FlutterInsider.Instance.getCurrentUser();
    insiderUser.setCustomAttributeWithString("key_str", "erdem");
    // insiderUser.setCustomAttributeWithString("key,str", null);
    insiderUser.setCustomAttributeWithInt("key_int", 122);
    insiderUser.unsetCustomAttribute("key_int");    //doğru ama neden set ederken value koyabılıyorum da unsette koyamıyorum.
    insiderUser.setCustomAttributeWithBoolean("key_bool", false);
    //  insiderUser.setCustomAttributeWithBoolean("key_bool",null);
    // insiderUser.setCustomAttributeWithDouble("key_double", 121212.12);
    insiderUser.setCustomAttributeWithDouble("key_double", null);
    insiderUser.setCustomAttributeWithDate("key_date", new DateTime.now());
    insiderUser.setCustomAttributeWithArray("key_array", arr);
    insiderUser.setCustomAttributeWithInt("key_str22222", 121);
    insiderUser.setBirthday(new DateTime.now());
    insiderUser.setName("aziz");
    insiderUser.setSurname("karayel");
    insiderUser.setFacebookID("face");
    insiderUser.setTwitterID("twit");
    insiderUser.setGender(InsiderGender.MALE);
    insiderUser.setEmail("azizkarayel@gmail.com");
    insiderUser.setPhoneNumber("12345678");
    insiderUser.setLanguage("arapca");
    insiderUser.setAge(23);
    insiderUser.setSMSOptin(true);
    insiderUser.setEmailOptin(false);
    insiderUser.setLocationOptin(true);
    //insiderUser.setLocationOptin(false);
    //insiderUser.login();
    insiderUser.logout();
    insiderUser.setUserIdentifierWithEmail("azizkarayel96@gmail.com");
    insiderUser.setUserIdentifierWithPhoneNumber("2323233223");
    insiderUser.setUserIdentifierWithUserID("131133");
    insiderUser.unsetUserIdentifierPhoneNumber();
    //event
    FlutterInsider.Instance.tagEvent("reg_event").build();
    FlutterInsider.Instance.tagEvent("reg_tag_ev")
        .addParameterWithBoolean("tag_bool", false)
        .addParameterWithDouble("tag_double", 22.2)
        .addParameterWithInt("tag_int", 122)
        .addParameterWithString("tag_str", "keko")
        .addParameterWithDate("tag_date", new DateTime.now())
        .addParameterWithArray("tag_arr", arr)
        .build();
  }

  Future<void> content() async {
    String content = await FlutterInsider.Instance.getContentStringWithName("variableName", "defaultValue", ContentOptimizerDataType.CONTENT);
    print(content);
  }

  Future<void> reco() async {
    Map recoo = await FlutterInsider.Instance.getSmartRecommendation(0, "tr_TR", "TRY");
    print(recoo);
  }

  Future<void> message() async {
    List messages = await FlutterInsider.Instance.getMessageCenterData(new DateTime(2019), new DateTime(2020), 20);
    print(messages);
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
            child: FlatButton(
          onPressed: () {
            content();
          },
          child: Text(_platformVersion),
          color: Colors.lightBlue,
        )),
      ),
    );
  }
}

==> flutter_insider-1.0.2.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';
import 'package:flutter_insider/flutter_insider.dart';
import 'package:flutter_insider/src/user.dart';
import 'package:flutter_insider/src/product.dart';
import 'package:flutter_insider/enum/InsiderGender.dart';
import 'package:flutter_insider/enum/InsiderCallbackAction.dart';
import 'package:flutter_insider/enum/ContentOptimizerDataType.dart';
import 'package:flutter_insider/enum/Vendors.dart';

void main() => runApp(MyApp());
class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}
class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  @override
  void initState() {
    super.initState();
    initInsider();
  }
  Future<void> initInsider() async {

    if (!mounted) return;
    await FlutterInsider.Instance.init("shopbagg", "test",
        (int type, dynamic data) {
      switch (type) {
        case InsiderCallbackAction.INAPP_BUTTON_CLICK:
          setState(() {
            _platformVersion = data.toString();
          });
          print("[INSIDER] : Callback Data: " + data.toString());
          break;
        case InsiderCallbackAction.NOTIFICATION_OPEN:
          setState(() {
            _platformVersion = data.toString();
          });
          print("[INSIDER] : Notification Callback Data: " + data.toString());
          break;
        default:
          print("[INSIDER] : Unregistered Action");
          break;
      }
    });
    FlutterInsider.Instance.registerWithQuietPermission(false); 
    // regression();
  }
  void regression() {
    FlutterInsider.Instance.startTrackingGeofence();
    FlutterInsider.Instance.registerWithQuietPermission(false);
    //   FlutterInsider.Instance.getSmartRecommendation(1, "tr_TR", "TRY");
    //FlutterInsider.Instance.getContentBoolWithName("variableName", true, 12);
    // FlutterInsider.Instance.getContentIntWithName("variableName", 12, 212);
    // FlutterInsider.Instance.getContentStringWithName("variableName", "defaultValue", 23);
    FlutterInsiderProduct pro = FlutterInsider.Instance.createNewProduct("ID-123", "name-123", "TAX-123", "IMG-123", 523.23, "CUR-123");  //doğru
    pro.setQuantity(3); //doğru
    FlutterInsider.Instance.itemPurchased("sale-001", pro); //doğru e_guid
    FlutterInsiderProduct pro1 = FlutterInsider.Instance.createNewProduct("ID-124", "name-124", "TAX-124", "IMG-124", 10, "CUR-124");
    FlutterInsider.Instance.itemAddedToCart(pro1); //doğru
    FlutterInsider.Instance.cartCleared(); //doğru
    FlutterInsiderProduct pro7 = FlutterInsider.Instance.createNewProduct("ID-1", "name-2", "TAX-3", "IMG-4", 12.34, "CUR-5");// item added to cartın içinde quantity otomatik 1 aldı set ettiklerim doğru geldi aşağıda
    FlutterInsider.Instance.itemAddedToCart(pro7);//doğru
    pro7.setQuantity(-2); //doğru pozitif olanı aldı
    pro7.setQuantity(20); // doğru
    pro7.setColor("maviiiii");// YANLIŞ GELMEDİ?????????
    pro7.setStock(null);
    pro7.setStock(-2);
    pro7.setColor("#2131321");
    pro7.setVoucherName("test_v");//gelmedi
    pro7.setPromotionName("test_p");// gelmedi
    pro7.setPromotionName("azz_pro"); // YANLIŞ GELMEDİ ???????????
    pro7.setSize("size_21");//gelmedi
    pro7.setStock(0); // st doğru
    pro7.setSalePrice(1231.2121); // usp doğru
    pro7.setShippingCost(23); // sc doğru
    pro7.setVoucherDiscount(0); // vd doğru
    pro7.setPromotionDiscount(2); // pd 2 doğru
    pro7.setCustomAttributeWithString("my_name", "test_string"); // YANLIS GELMEDİİİİİİİİİİİİİİİİİİ ?
    pro7.setCustomAttributeWithBoolean("is_got", true); //doğru
    pro7.setCustomAttributeWithInt("inte_ger", 121212);//doğru
    pro7.setCustomAttributeWithDouble("double_double", 33333.2); // doğru
    pro7.setCustomAttributeWithDate("zaman_dursun", new DateTime.now()); //doğru
    pro7.setSubCategory("leg");//gelmedi
    List<String> trr = new List(4);
    trr[0] = "deneme1";
    trr[1] = "deneme22";
    trr[2] = "deneme3";
    trr[3] = null;
    pro7.setCustomAttributeWithArray("test_keko", trr); // doğru bosluklu yollayınca valid değil diyor.
    FlutterInsider.Instance.itemPurchased("123", pro7); // doğru e_guid
    FlutterInsiderProduct pro4 = FlutterInsider.Instance.createNewProduct(
        "ID-120", "name-120", "TAX-120", "IMG-120", 12.34, "CUR-120");
    pro4.setQuantity(4);
    FlutterInsider.Instance.itemPurchased(null, null);
    FlutterInsiderProduct pro3 = FlutterInsider.Instance.createNewProduct(
        "ID-122", "name-122", "TAX-122", "IMG-122", 12.34, "CUR-122");
    pro3.setQuantity(0);
    FlutterInsider.Instance.itemAddedToCart(pro3);
    List<FlutterInsiderProduct> products = new List(2);
    products[0] = pro4;
    products[1] = pro3;
    FlutterInsider.Instance.visitCartPage(products);
    FlutterInsider.Instance.visitHomePage(); //doğru
    // FlutterInsider.Instance.visitListingPage(null);
    FlutterInsider.Instance.visitListingPage("shooes");
    //   FlutterInsider.Instance.visitProductDetailPage(null);//doğru
    FlutterInsider.Instance.visitProductDetailPage(pro4);
    FlutterInsider.Instance.itemRemovedFromCart("5"); //doğru
    FlutterInsider.Instance.setGDPRConsent(true);
    //FlutterInsider.Instance.setGDPRConsent(false);
    List<String> arr = new List(4);
    arr[0] = "item1";
    arr[1] = "item2";
    arr[2] = "item3";
    arr[3] = null;
    //user
    DateTime time = new DateTime.now();
    FlutterInsiderUser insiderUser = FlutterInsider.Instance.getCurrentUser();
    insiderUser.setCustomAttributeWithString("key_str", "erdem");
    // insiderUser.setCustomAttributeWithString("key,str", null);
    insiderUser.setCustomAttributeWithInt("key_int", 122);
    insiderUser.unsetCustomAttribute("key_int");    //doğru ama neden set ederken value koyabılıyorum da unsette koyamıyorum.
    insiderUser.setCustomAttributeWithBoolean("key_bool", false);
    //  insiderUser.setCustomAttributeWithBoolean("key_bool",null);
    // insiderUser.setCustomAttributeWithDouble("key_double", 121212.12);
    insiderUser.setCustomAttributeWithDouble("key_double", null);
    insiderUser.setCustomAttributeWithDate("key_date", new DateTime.now());
    insiderUser.setCustomAttributeWithArray("key_array", arr);
    insiderUser.setCustomAttributeWithInt("key_str22222", 121);
    insiderUser.setBirthday(new DateTime.now());
    insiderUser.setName("aziz");
    insiderUser.setSurname("karayel");
    insiderUser.setFacebookID("face");
    insiderUser.setTwitterID("twit");
    insiderUser.setGender(InsiderGender.MALE);
    insiderUser.setEmail("azizkarayel@gmail.com");
    insiderUser.setPhoneNumber("12345678");
    insiderUser.setLanguage("arapca");
    insiderUser.setAge(23);
    insiderUser.setSMSOptin(true);
    insiderUser.setEmailOptin(false);
    insiderUser.setLocationOptin(true);
    //insiderUser.setLocationOptin(false);
    //insiderUser.login();
    insiderUser.logout();
    insiderUser.setUserIdentifierWithEmail("azizkarayel96@gmail.com");
    insiderUser.setUserIdentifierWithPhoneNumber("2323233223");
    insiderUser.setUserIdentifierWithUserID("131133");
    insiderUser.unsetUserIdentifierPhoneNumber();
    //event
    FlutterInsider.Instance.tagEvent("reg_event").build();
    FlutterInsider.Instance.tagEvent("reg_tag_ev")
        .addParameterWithBoolean("tag_bool", false)
        .addParameterWithDouble("tag_double", 22.2)
        .addParameterWithInt("tag_int", 122)
        .addParameterWithString("tag_str", "keko")
        .addParameterWithDate("tag_date", new DateTime.now())
        .addParameterWithArray("tag_arr", arr)
        .build();
  }

  Future<void> content() async {
    List<int> vendors = new List();
    vendors.add(Vendors.OPPO);
    vendors.add(Vendors.XIAOMI);
    FlutterInsider.Instance.getAutoStartPermission(vendors);
    // String content = await FlutterInsider.Instance.getContentStringWithName("variableName", "defaultValue", ContentOptimizerDataType.CONTENT);
    // print(content);
  }

  Future<void> reco() async {
    Map recoo = await FlutterInsider.Instance.getSmartRecommendation(0, "tr_TR", "TRY");
    print(recoo);
  }

  Future<void> message() async {
    List messages = await FlutterInsider.Instance.getMessageCenterData(new DateTime(2019), new DateTime(2020), 20);
    print(messages);
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
            child: FlatButton(
          onPressed: () {
            content();
          },
          child: Text(_platformVersion),
          color: Colors.lightBlue,
        )),
      ),
    );
  }
}
